@@ -5,19 +5,16 @@ import sys
 import textwrap
 
 # internal modules
-from termkeymonitor import find_keyboard_device, stop_on_keyboardinterrupt
+from termkeymonitor import (
+    find_keyboard_device,
+    stop_on_keyboardinterrupt,
+    make_argparser,
+    key_pretty,
+)
 
 # external modules
 import evdev
 
-parser = argparse.ArgumentParser("Show pressed keys")
-parser.add_argument(
-    "-d",
-    "--device",
-    help="Input device to watch (e.g. /dev/input/event4)",
-    type=evdev.InputDevice,
-)
-
 
 def print_centered(s):
     s = textwrap.shorten(
@@ -29,6 +26,7 @@ def print_centered(s):
 
 @stop_on_keyboardinterrupt
 def cli():
+    parser = make_argparser()
     args = parser.parse_args()
     if args.device is None:
         print_centered("\r🔎 Searching for input devices...")
@@ -41,12 +39,15 @@ def cli():
     for event in args.device.read_loop():
         if event.type == evdev.ecodes.EV_KEY:
             line = " ".join(
-                name.removeprefix("KEY_")
+                key_pretty(
+                    name=name,
+                    code=code,
+                    keymap=args.keymap,
+                    show_code=args.show_code,
+                )
                 for name, code in args.device.active_keys(verbose=True)
             )
-            print_centered(
-                f"\r{{:^{os.get_terminal_size().columns}s}}".format(line)
-            )
+            print_centered(line)
 
 
 if __name__ == "__main__":
